google.charts.load('48', {packages: ['corechart', 'line']});
google.charts.setOnLoadCallback(generateCheckboxes);

function generateCheckboxes() {
    var controlsDiv = document.getElementById('controls');
    var rows = 'ABCDEFGH';

    // 各列に全選択チェックボックスを追加
    for (var i = 0; i < 12; i++) {
        var columnDiv = document.createElement('div');
        columnDiv.className = 'checkbox-column';

        // 全選択チェックボックス
        var labelAll = document.createElement('label');
        var checkboxAll = document.createElement('input');
        checkboxAll.type = 'checkbox';
        checkboxAll.id = 'selectAll' + i;
        checkboxAll.addEventListener('change', function(event) {
            selectAllInColumn(event.target.id);
        });
        labelAll.appendChild(checkboxAll);
        labelAll.appendChild(document.createTextNode(' All ' + (i + 1)));
        labelAll.className = 'all-select-label';
        columnDiv.appendChild(labelAll);

        // 各行のチェックボックス
        for (var j = 0; j < rows.length; j++) {
            var label = document.createElement('label');
            var checkbox = document.createElement('input');
            checkbox.type = 'checkbox';
            checkbox.value = j * 12 + i;
            checkbox.checked = true;
            label.appendChild(checkbox);
            label.appendChild(document.createTextNode(' ' + rows[j] + (i + 1)));
            columnDiv.appendChild(label);
        }

        controlsDiv.appendChild(columnDiv);
    }

    // 全列に対する全選択チェックボックスを追加
    var allSelectDiv = document.createElement('div');
    allSelectDiv.className = 'checkbox-column';
    var labelAll = document.createElement('label');
    var checkboxAll = document.createElement('input');
    checkboxAll.type = 'checkbox';
    checkboxAll.id = 'selectAllAll';
    checkboxAll.addEventListener('change', function(event) {
        selectAllInAllColumns(event.target.checked);
    });
    labelAll.appendChild(checkboxAll);
    labelAll.appendChild(document.createTextNode(' Select All'));
    labelAll.className = 'column-header';
    allSelectDiv.appendChild(labelAll);
    controlsDiv.appendChild(allSelectDiv);
}

function selectAllInColumn(columnId) {
    var index = parseInt(columnId.replace('selectAll', ''));
    var checkboxes = document.querySelectorAll('#controls input[type=checkbox]');
    var isChecked = document.getElementById(columnId).checked;
    checkboxes.forEach(function(checkbox) {
        if (checkbox.value !== undefined) {
            var checkboxIndex = parseInt(checkbox.value);
            if (checkboxIndex % 12 === index) {
                checkbox.checked = isChecked;
            }
        }
    });
}

function selectAllInAllColumns(checked) {
    var checkboxes = document.querySelectorAll('#controls input[type=checkbox]');
    checkboxes.forEach(function(checkbox) {
        if (checkbox.value !== undefined) {
            checkbox.checked = checked;
        }
    });
}




function drawGID() {
  var url = document.getElementById('spreadsheetUrl').value;
  var sheetName = document.getElementById('sheetName').value;
  var yAxisRange = document.getElementById('yAxisRange').value.split(',').map(Number);
  var xAxisRange = document.getElementById('xAxisRange').value.split(',').map(Number);

  var queryString = encodeURIComponent('SELECT C, D LIMIT 86445');

  var query = new google.visualization.Query(
      `${url}/gviz/tq?sheet=${encodeURIComponent(sheetName)}&range=C1:G86445&headers=1&tq=${queryString}`);
  query.send(function(response) {
      handleQueryResponse(response, yAxisRange, xAxisRange);
  });
}



function handleQueryResponse(response, yAxisRange, xAxisRange) {
    if (response.isError()) {
        console.error('Error in query:', response.getMessage(), response.getDetailedMessage());
        return;
    }

    var data = response.getDataTable();

    // D列の数値形式を変更する
    for (var i = 0; i < data.getNumberOfRows(); i++) {
        var value = data.getValue(i, 1); // D列はインデックス1
        if (typeof value === 'number') {
            data.setValue(i, 1, parseFloat(value.toFixed(3))); // 数値を小数点以下3桁に変更
        }
    }

    // データを再構成する
    var datalined = [];
    for (var i = 0; i < data.getNumberOfRows() / 96; i++) {
        datalined[i] = [i];
        for (var j = 0; j < 96; j++) {
            datalined[i].push(data.getValue(i * 96 + j, 1));
        }
    }

    // ユーザーが選択した系列のみを表示する
    var selectedSeries = [];
    var checkboxes = document.querySelectorAll('#controls input[type=checkbox]');
    checkboxes.forEach(function(checkbox) {
        if (checkbox.checked && checkbox.value !== undefined) {
            selectedSeries.push(parseInt(checkbox.value) + 1); // +1 to account for the index column
        }
    });

    if (selectedSeries.length === 0) {
        alert('Please select at least one series to display.');
        return;
    }

    // 選択された系列のみを含む新しいDataTableを作成する
    var newData = new google.visualization.DataTable();
    newData.addColumn('number', 'Index');
    for (var k = 0; k < selectedSeries.length; k++) {
        newData.addColumn('number', 'Value ' + (selectedSeries[k]));
    }

    for (var i = 0; i < datalined.length; i++) {
        var row = [datalined[i][0]];
        for (var k = 0; k < selectedSeries.length; k++) {
            row.push(datalined[i][selectedSeries[k]]);
        }
        newData.addRow(row);
    }

    var chartOptions = {
      height: 400,
      colors: ['#47453B','#00796B','#228A63','#449A5A','#67AB52','#89BB4A','#ABCC41','#CDDC39'],
      
      vAxis: {
          viewWindow: {
              min: yAxisRange[0],
              max: yAxisRange[1]
          }
      },
      hAxis: {
          viewWindow: {
              min: xAxisRange[0],
              max: xAxisRange[1]
          }
      }
      
  };

    var chart = new google.visualization.LineChart(document.getElementById('chart_div'));
    chart.draw(newData, chartOptions);
}
